@@ -4,9 +4,9 @@ from tron.core.app.base_configurations.configMapSecretApproval import ConfigMapS
 
 class DevtronConfigMapSecret:
     def __init__(self, base_url, headers):
-        self.base_url = base_url
-        self.headers = headers
-        self.devtron_utils = DevtronUtils(base_url, headers)
+        self.base_url        = base_url
+        self.headers         = headers
+        self.devtron_utils   = DevtronUtils(base_url, headers)
         self.config_approval = ConfigMapSecretApproval(base_url, headers)
 
     def create_secret(self, app_id, secret_data, config_approval_in_base_secret=None, id=None):
@@ -105,6 +105,8 @@ class DevtronConfigMapSecret:
                     return {'success': False, 'error': f'API request failed: {response.text}'}
         except Exception as e:
             return {'success': False, 'error': f'Exception occurred: {str(e)}'}
+
+
     def delete_secret(self, app_id, secret_name, resourceConfigId):
         url = f"{self.base_url}/orchestrator/config/global/cs/{app_id}/{resourceConfigId}?name={secret_name}&isExpressEdit=false"
         headers = dict(self.headers)
@@ -114,6 +116,8 @@ class DevtronConfigMapSecret:
             return {'success': True, 'message': 'Secret deleted successfully'}
         else:
             return {'success': False, 'error': f'API request failed: {response.text}'}
+
+
     def create_config_map(self, app_id, config_map_data, config_approval_in_base_config_map=False, id=None):
         """
         Create a config map (CM) for the given app_id in Devtron.
@@ -229,7 +233,9 @@ class DevtronConfigMapSecret:
             else:
                 return {'success': False, 'error': f'API request failed: {response.text}'}
         except Exception as e:
-            return {'success': False, 'error': f'API request failed: {str(e)}'}    
+            return {'success': False, 'error': f'API request failed: {str(e)}'}
+
+
     def get_base_cm_cs_details(self, app_id):
         # getting cm cs from the applications then will decide whom to delete and to create new one
         try:
@@ -342,8 +348,88 @@ class DevtronConfigMapSecret:
                 return {'success': False, 'error': f'API request failed: {response.text}'}
         except Exception as e:
             return {'success': False, 'error': f'Exception occurred: {str(e)}'}
-        
-    def update_base_cm_cs(self,config_data,config_approval_in_base_config_map=None,config_approval_in_base_secret=None):
+
+    def is_cm_cs_modified(self, app_id: int, new_config: dict, resource_type: str):
+        """
+        Compares the new_config with the current config in devtron to check for modifications.
+        Args:
+            app_id (int): The application ID.
+            new_config (dict): The new configuration data for the ConfigMap or Secret.
+            resource_type (str): The type of resource, either 'cm' for ConfigMap or 'cs' for Secret.
+
+        Returns:
+            dict: {'success': bool, 'modified': bool, 'error': str}
+        """
+        try:
+            if not new_config or 'name' not in new_config:
+                return {"success": False, "modified": False, "error": "The config was not provided or is missing a name."}
+
+            config_name = new_config['name']
+
+            if resource_type == 'cm':
+                details_result = self.get_config_map_details(app_id, config_name)
+                current_config = details_result.get('config_map')
+            elif resource_type == 'cs':
+                details_result = self.get_secret_details(app_id, config_name)
+                current_config = details_result.get('secret')
+            else:
+                return {"success": False, "modified": False, "error": f"Invalid resource_type: {resource_type}"}
+
+            if not details_result['success'] or not current_config:
+                # If it doesn't exist, it's not a modification but a creation, but for safety we can say not modified.
+                return {"success": False, "modified": False, "error": f"Could not fetch current details for {config_name}."}
+
+            # Fields to compare
+            fields_to_check = [
+                'type', 'external', 'data', 'mountPath', 'subPath',
+                'filePermission', 'externalType', 'roleARN', 'mergeStrategy'
+            ]
+
+
+            default_values = {
+                'name': "",
+                'type': "volume",
+                'external': False,
+                'data': {},
+                'mountPath': "",
+                'subPath': "",
+                'filePermission': "",
+                'externalType': "",
+                'roleARN': "",
+                'mergeStrategy': "",
+                'patchData': None,
+                'global': True,
+                'esoSecretData': None,
+                'defaultESOSecretData': None,
+                'esoSubPath': None
+            }
+            if new_config.get("subPath", ""):
+                default_values["type"] = "volume"
+            else:
+                default_values["type"] = "environment"
+
+            for field in fields_to_check:
+
+                new_value = new_config.get(field, default_values.get(field))
+                current_value = current_config.get(field, default_values.get(field))
+
+                # Normalize 'data' field for comparison if it's None or empty
+                if field == 'data':
+                    new_value = new_value or {}
+                    current_value = current_value or {}
+
+                if new_value != current_value:
+                    return {"success": True, "modified": True}
+
+            return {"success": True, "modified": False}
+
+        except Exception as e:
+            return {'success': False, 'modified': False, 'error': f'Exception occurred: {str(e)}'}
+
+
+
+
+    def update_base_cm_cs(self, config_data: dict = None, config_approval_in_base_config_map=None,config_approval_in_base_secret=None, allow_deletion=False):
         app_id = self.devtron_utils.get_application_id_by_name(config_data.get('app_name')).get('app_id')
         get_base_cm_cs_details_result = self.get_base_cm_cs_details(app_id)
         if not get_base_cm_cs_details_result['success']:
@@ -351,12 +437,11 @@ class DevtronConfigMapSecret:
                 'success': False,
                 'error': f"Failed to fetch existing config maps and secrets: {get_base_cm_cs_details_result['error']}"
             }
-        existing_cm_cs = get_base_cm_cs_details_result.get('result', {})
-        existing_cm_names = existing_cm_cs.get('cm_list', [])
+        existing_cm_cs        = get_base_cm_cs_details_result.get('result', {})
+        existing_cm_names     = existing_cm_cs.get('cm_list', [])
+        resource_config_id    = existing_cm_cs.get('resourceConfigId', None)
         existing_secret_names = existing_cm_cs.get('cs_list', [])
-        resourceConfigId = existing_cm_cs.get('resourceConfigId', None) #used to delete or update cm/cs
 
-        # print(existing_cm_names, existing_secret_names, resourceConfigId)
 
         current_cm_names = [item.get('name') for item in config_data.get('base_configurations', {}).get('config_maps', [])]
         current_cs_names = [item.get('name') for item in config_data.get('base_configurations', {}).get('secrets', [])]
@@ -382,6 +467,35 @@ class DevtronConfigMapSecret:
                 # Item exists in current but not in existing → mark it for creation
                 cm_to_create.append(item)
 
+        # Start by assuming all existing secrets need to be deleted
+        cs_to_delete = existing_secret_names
+        for item in current_cs_names:
+            if item in existing_secret_names:
+                # Item exists in both current and existing → mark it for update
+                cs_to_update.append(item)
+
+                # Remove from delete list since it exists in both
+                cs_to_delete.remove(item)
+            else:
+                # Item exists in current but not in existing → mark it for creation
+                cs_to_create.append(item)
+
+        # Check if there are any deletions and if allow_deletion is False
+        if (cm_to_delete or cs_to_delete) and not allow_deletion:
+            deletion_list = []
+            if cm_to_delete:
+                deletion_list.extend([f"ConfigMap: {name}" for name in cm_to_delete])
+            if cs_to_delete:
+                deletion_list.extend([f"Secret: {name}" for name in cs_to_delete])
+            
+            deletion_message = "The following resources will be deleted:\n" + "\n".join(deletion_list)
+            deletion_message += "\n\nTo proceed with deletion, please add the --allow-deletion flag to the update-app command."
+            
+            return {
+                'success': False,
+                'error': f'Deletion requires explicit approval. {deletion_message}'
+            }
+
         cm_data = config_data.get('base_configurations', {}).get('config_maps')
         cm_to_create_data=[]
         cm_to_update_data=[]
@@ -398,36 +512,24 @@ class DevtronConfigMapSecret:
             if cm.get('name') in cm_to_create:
                 cm_to_create_data.append(cm)
             if cm.get('name') in cm_to_update:
-                cm_to_update_data.append(cm)
-
+                if_cm_has_changes = self.is_cm_cs_modified(app_id, cm, "cm")
+                if if_cm_has_changes.get("modified", True):
+                    cm_to_update_data.append(cm)
         for item in cm_to_create_data:
             cm_result = self.create_config_map(app_id, item, config_approval_in_base_config_map)
             if not cm_result['success']:
                 return {'success': False, 'error': f"Failed to create config map: {cm_result['error']}"}
 
         for item in cm_to_update_data:
-            cm_result = self.create_config_map(app_id, item,config_approval_in_base_config_map,id=resourceConfigId)
+            cm_result = self.create_config_map(app_id, item,config_approval_in_base_config_map,id=resource_config_id)
             if not cm_result['success']:
                 return {'success': False, 'error': f"Failed to update config map: {cm_result['error']}"}
         
         for item in cm_to_delete:
-            cm_result = self.delete_config_map( app_id, item,config_approval_in_base_config_map, resourceConfigId)
+            cm_result = self.delete_config_map( app_id, item,config_approval_in_base_config_map, resource_config_id)
             if not cm_result['success']:
                 return {'success': False, 'error': f"Failed to delete config map: {cm_result['error']}"}
 
-        # Start by assuming all existing secrets need to be deleted
-        cs_to_delete = existing_secret_names
-        for item in current_cs_names:
-            if item in existing_secret_names:
-                # Item exists in both current and existing → mark it for update
-                cs_to_update.append(item)
-
-                # Remove from delete list since it exists in both
-                cs_to_delete.remove(item)
-            else:
-                # Item exists in current but not in existing → mark it for creation
-                cs_to_create.append(item)
-
         cs_data = config_data.get('base_configurations', {}).get('secrets')
         cs_to_create_data=[]
         cs_to_update_data=[] 
@@ -451,11 +553,11 @@ class DevtronConfigMapSecret:
                 return {'success': False, 'error': f"Failed to create secret: {cs_result['error']}"}
         for item in cs_to_update_data:
             secret_b64 = self.devtron_utils.makebase64(item)
-            cs_result = self.create_secret(app_id, secret_b64, config_approval_in_base_secret, id=resourceConfigId)
+            cs_result = self.create_secret(app_id, secret_b64, config_approval_in_base_secret, id=resource_config_id)
             if not cs_result['success']:
                 return {'success': False, 'error': f"Failed to update secret: {cs_result['error']}"}
         for item in cs_to_delete:
-            cs_result = self.delete_secret( app_id, item, config_approval_in_base_secret, resourceConfigId)
+            cs_result = self.delete_secret( app_id, item, config_approval_in_base_secret)
             if not cs_result['success']:
                 return {'success': False, 'error': f"Failed to delete secret: {cs_result['error']}"}     
         return {'success': True, 'message': 'Base config map and secret operations completed successfully.'}
