@@ -171,7 +171,7 @@ class CiPipelineHandlers:
                 for version in plugin.get("pluginVersions", {}).get("detailedPluginVersionData", []):
                     (plugin_name, plugin_version) = (version.get("name", ""), version.get("pluginVersion", ""))
 
-                    if (plugin_name, plugin_version) is not ("", ""):
+                    if (plugin_name, plugin_version) != ("", ""):
                         plugin_minimal_data[(plugin_name, plugin_version)] = version
 
             plugin_name = ""
@@ -230,18 +230,20 @@ class CiPipelineHandlers:
                     break
 
             input_variables = []
-            for input_variable in plugin.get("inputVariables", []):
+            if plugin.get("inputVariables", []):
 
-                input_variables.append(InputVariable(
-                    allow_empty_value=input_variable.get("allowEmptyValue", False),
-                    description=input_variable.get("description", ""),
-                    _format=input_variable.get("format", "STRING"),
-                    _id=input_variable.get("id", 0),
-                    name=input_variable.get("name", ""),
-                    value=step.get("input_variables", {}).get(input_variable.get("name", ""), ""),
-                    value_constraint=None,
-                    variable_type="NEW"
-                ))
+                for input_variable in plugin.get("inputVariables", []):
+
+                    input_variables.append(InputVariable(
+                        allow_empty_value=input_variable.get("allowEmptyValue", False),
+                        description=input_variable.get("description", ""),
+                        _format=input_variable.get("format", "STRING"),
+                        _id=input_variable.get("id", 0),
+                        name=input_variable.get("name", ""),
+                        value=step.get("input_variables", {}).get(input_variable.get("name", ""), ""),
+                        value_constraint=None,
+                        variable_type="NEW"
+                    ))
 
             plugin_ref_step_detail = PluginRefStepDetail(
                     plugin_id=plugin.get("id", 0),
