@@ -615,6 +615,37 @@ class DevtronUtils:
                 "error": str(e)
             }
 
+    @staticmethod
+    def get_wf_id_from_cd_id(base_url, headers, ci_id, app_id):
+        try:
+            url = f"{base_url}/orchestrator/app/app-wf/{app_id}"
+
+            response = requests.get(url, headers=headers)
+            if response.status_code != 200:
+                return {
+                    "success": False,
+                    "error": "Failed to get wf ID"
+                }
+            result = response.json().get("result", {})
+            for wf in result.get("workflows", []):
+                for node in wf.get("tree", []):
+                    if node.get("componentId", 0) == ci_id:
+                        return {
+                            "success": True,
+                            "wf_id": node.get("appWorkflowId")
+                        }
+            return {
+                "success": False,
+                "error": "Workflow not found for given CI"
+            }
+
+
+        except Exception as e:
+            return {
+                "success": False,
+                "error": "Failed to get wf ID"
+            }
+
     @staticmethod
     def get_plugin_details_by_name(base_url, headers, plugin_name: str) -> dict:
         try:
